package
Version:
v0.0.0-...-f0e47c8
Opens a new window with list of versions in this module.
Published: Mar 11, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BridgeConfig struct {
CommandPrefix string `yaml:"command_prefix"`
}
BridgeConfig tweaks Matrix-side behaviour shared across all AI bridges.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.