providerkit

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ApplyDefaults

func ApplyDefaults(provider *string, fallbacks *[]string, defaultProvider string, defaultFallbacks []string)

ApplyDefaults fills empty provider selection fields with the package defaults.

func ApplyNamedEnv

func ApplyNamedEnv(provider *string, fallbacks *[]string, envProvider, envFallbacks string)

ApplyNamedEnv fills empty provider selection fields from the provided env values.

Types

This section is empty.

Jump to